@@ -110,7 +110,7 @@ BEGIN {
 		);
 	};
 
-$VERSION = "2.09_01";
+$VERSION = "2.09_02";
 
 sub ARTICLE_CODE_OUT_OF_RANGE () { -5 }
 sub INVALID_PREFIX            () { -4 };
@@ -539,8 +539,15 @@ sub xisbn {
 	my $data = $self->_get_xisbn;
 	$data =~ tr/x/X/;
 
-	my $dom = Mojo::DOM->new( $data );
-	my @isbns = $dom->find( 'isbn' )->map('text')->each;
+	my @isbns = do {
+		if( eval "require Mojo::DOM; 1" ) {
+			my $dom = Mojo::DOM->new( $data );
+			$dom->find( 'isbn' )->map('text')->each;
+			}
+		else {
+			$data =~ m|<isbn.*?>(.*?)</isbn>|g;
+			}
+		};
 
 	shift @isbns;
 	wantarray ? @isbns : \@isbns;
